Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: include/gpu/GrDistanceFieldTextContext.h

Issue 41213003: Hook in rough distance field support for fonts (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: Minor fixes for GrDistanceFieldTextContext. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: include/gpu/GrDistanceFieldTextContext.h
diff --git a/include/gpu/GrBitmapTextContext.h b/include/gpu/GrDistanceFieldTextContext.h
similarity index 67%
copy from include/gpu/GrBitmapTextContext.h
copy to include/gpu/GrDistanceFieldTextContext.h
index e0900ecd7d625629418dd26e29a40d6617070bee..f5015e2e3dde249b2375e2998b80b218399bd8e0 100755
--- a/include/gpu/GrBitmapTextContext.h
+++ b/include/gpu/GrDistanceFieldTextContext.h
@@ -5,27 +5,27 @@
* found in the LICENSE file.
*/
-#ifndef GrBitmapTextContext_DEFINED
-#define GrBitmapTextContext_DEFINED
+#ifndef GrDistanceFieldTextContext_DEFINED
+#define GrDistanceFieldTextContext_DEFINED
#include "GrTextContext.h"
class GrTextStrike;
/*
robertphillips 2013/11/05 15:30:26 remove "standard"?
jvanverth1 2013/11/05 17:09:22 Done.
* This class implements GrTextContext using standard bitmap fonts
*/
-class GrBitmapTextContext : public GrTextContext {
+class GrDistanceFieldTextContext : public GrTextContext {
public:
- GrBitmapTextContext(GrContext*, const GrPaint&, SkColor);
- virtual ~GrBitmapTextContext();
+ GrDistanceFieldTextContext(GrContext*, const GrPaint&, SkColor, SkScalar textSize);
+ virtual ~GrDistanceFieldTextContext();
virtual void drawPackedGlyph(GrGlyph::PackedID, GrFixed left, GrFixed top,
robertphillips 2013/11/05 15:30:26 indent here?
jvanverth1 2013/11/05 17:09:22 Done.
GrFontScaler*) SK_OVERRIDE;
private:
- GrContext::AutoMatrix fAutoMatrix;
- GrTextStrike* fStrike;
+ GrTextStrike* fStrike;
+ SkScalar fTextSize;
void flushGlyphs(); // automatically called by destructor
robertphillips 2013/11/05 15:30:26 If this is required in both GrBitmapTextContext an
jvanverth1 2013/11/05 17:09:22 Not necessarily -- GrNVPathRenderingTextContext (o
@@ -5,27 +5,27 @@
robertphillips 2013/11/05 15:30:26 remove "standard"?
jvanverth1 2013/11/05 17:09:22 Done.
- * This class implements GrTextContext using standard bitmap fonts
+ * This class implements GrTextContext using standard DistanceField fonts
*/

Powered by Google App Engine
This is Rietveld 408576698